#
# spec file for package getdp
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           getdp
Version:        2.11.2
Release:        lp150.1.23
%define lib_ver 2_11
Url:            http://geuz.org/getdp/
Summary:        A general finite element solver
License:        GPL-2.0+
Group:          Productivity/Scientific/Math
Source0:        http://geuz.org/getdp/src/getdp-%{version}-source.tgz
# PATCH-FIX-UPSTREAM http://gitlab.onelab.info/getdp/getdp/commit/c53529ffaa4c42130c2b6799441cf8d164f85343
Patch0:         getdp-2.11.2-reproducible-date.patch
%if 0%{?suse_version} <= 120300
# PATCH-FIX-OPENSUSE fix command line options for makeinfo on OpenSuSE <= Leap 42.3
Patch1:         getdp-2.11.2-fix-doc-build.patch
%endif
BuildRequires:  arpack-devel
BuildRequires:  bison
BuildRequires:  blas-devel
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gsl-devel
BuildRequires:  lapack-devel
%if 0%{?suse_version} == 1110
BuildRequires:  texlive-latex
%endif
BuildRequires:  texinfo
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GetDP is a general finite element solver using mixed elements to discretize
de Rham-type complexes in one, two and three dimensions. The main feature of
GetDP is the closeness between the input data defining discrete problems
(written by the user in ASCII data files) and the symbolic mathematical 
expressions of these problems.  

%package     -n libGetDP%{lib_ver}
Summary:        A general finite element solver
Group:          System/Libraries
Provides:       libGetDP = %{version}
Obsoletes:      libGetDP < %{version}

%description -n libGetDP%{lib_ver}
GetDP is a general finite element solver using mixed elements to discretize
de Rham-type complexes in one, two and three dimensions. The main feature of
GetDP is the closeness between the input data defining discrete problems
(written by the user in ASCII data files) and the symbolic mathematical 
expressions of these problems.  

%package        devel
Summary:        Header files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libGetDP = %{version}

%description    devel
This package contains libraries and header files for getdb.

%package        doc
Summary:        A general finite element solver
Group:          Documentation/Other
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description    doc
GetDP is a general finite element solver using mixed elements to discretize
de Rham-type complexes in one, two and three dimensions. The main feature of
GetDP is the closeness between the input data defining discrete problems
(written by the user in ASCII data files) and the symbolic mathematical 
expressions of these problems.

This package contains the documentation files (pdf and html) and some examples
files.

%prep
%setup -q -n %{name}-%{version}-source
%patch0 -p1
%if 0%{?suse_version} <= 120300
%patch1 -p1
%endif

sed -i "s/\${GETDP_LIB}/\${LIB_DIR}/" CMakeLists.txt

%build
%cmake \
    -DENABLE_BUILD_SHARED:BOOL=ON \
    -DLIB_DIR:PATH=%{_lib}

make %{?_smp_mflags}
make doc

%install
%cmake_install

# documentation
rm -rf %{buildroot}%{_datadir}/doc/%{name}
pushd build
tar xzf %{name}-%{version}-doc.tgz
popd

%post -n libGetDP%{lib_ver} -p /sbin/ldconfig
%postun -n libGetDP%{lib_ver} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc LICENSE.txt CHANGELOG.txt README.txt
%{_bindir}/*
%{_mandir}/man1/*

%files -n libGetDP%{lib_ver}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/*.so

%files doc
%defattr(-,root,root)
%doc build/doc/texinfo/getdp.html
%doc build/doc/texinfo/getdp.pdf
%doc demos/

%changelog
* Tue Oct 31 2017 dan.weatherill@cantab.net
- update to version 2.11.2
  * minor build system changes
  2.11.1
  * small bug fixes & improvements
  2.11.0
  * small improvements in math functions
  * bug fixes
  2.10.0
  * ONELAB 1.3 usability & perf improvements
  2.9.2
  * small bug fixes
  2.9.1
  * small improvements & bug fixes
  2.9.0
  * new ONELAB 1.2 protocol
  * new functions (Min, Max, SetDTime)
  * small fixes
  2.8.0
  * added support for list of strings
  * various improvements and bugfixes for ONELAB
  2.7.0
  * new Else/ElseIf commands
  * new timing and memory reporting functions
  2.6.1
  * enhanced Print[] command
  * minor fixes
  2.6.0
  * new ability to define and use Macros in .pro files
  * new run time variables
  * new Append*ToFileName PostOperation options
  * new GetResidual and associated operations
  * extend format support in MSH file reader
  * fixed UpdateCOnstraint for complex-simulated-real and
    multi-harmonic calculations
  2.5.1
  * enhanced Python[] and DefineFunction[]
  2.6.0
  * added option to embed Octave and Python interpreters
  * extended "Field" functions with gradient
  * extended string and list handling functions
  * new resolution and postprocessing functions
  * extended EigenSolve with eigenvalue filter and high
    order polynomial EV problems
  * small bug fixes
- refresh patch getdp-2.4.4-reproducible-date.patch to
  getdp-2.11.2-reproducible-date.patch so it applies
  successfully
- VERSIONS.txt has been renamed to CHANGELOG.txt
- add patch getdp-2.11.2-fix-doc-build.patch to
  allow building info doc on OpenSuse <=42.3
* Tue Jul 25 2017 bwiedemann@suse.com
- Add getdp-2.4.4-reproducible-date.patch to not have build date
  in getdp binary (boo#1047218)
* Sat Feb 28 2015 dmitry_r@opensuse.org
- Update to version 2.4.4
  * new two-step Init constraints
  * faster network computation (with new -cache)
  * improved Update operation
  * better cpu/memory reporting
  * new -setnumber, -setstring and -gmshread command line options
- Drop obsolete getdp-2.3.0-libdir.patch, getdp-2.3.0-soversion.patch
* Wed Mar 27 2013 scorot@free.fr
- version 2.3.0
  * new family of Field functions to use data imported from Gmsh
  * improved list handling
  * general code cleanup
- build shared library
- add patches:
  - getdp-2.3.0-libdir.patch
  - getdp-2.3.0-soversion.patch
- remove patch:
  - getdp-2.1.0-install.patch
* Sat Jul 21 2012 scorot@free.fr
- version 2.2.1
  * cleaned up nonlinear convergence tests
  * integrated experimental adaptive time loop code
  * small bug fixes
* Sat Jun  2 2012 scorot@free.fr
- spec file re-formating
- version 2.1.1
  * no changelog provided
